# GoodGame
A Simple API for making games
# Docs
TODO, but you can see examples and code itself
# Standards
 - time: seconds (float)
 - rect / point: array (int or float)
 - color: array (int or float)
# Examples
[test](main.py)
# TODO
 - See [here](https://github.com/Pyxelsuft/goodgame/search?q=TODO&type=)
